==> react-block-highlight-1.0.2-0.tgz: package/es/index.js <==
import React, { useEffect, useRef } from "react";
import PropTypes from 'prop-types';
/**
 * React Component to highlight any part of the containing block in reactangle size.
 */

var ReactBlockHighlighter = function ReactBlockHighlighter(_ref) {
  var id = _ref.id,
      x = _ref.x,
      y = _ref.y,
      height = _ref.height,
      width = _ref.width,
      opacity = _ref.opacity,
      color = _ref.color;

  var canvasRef = useRef(null);
  var ctx = useRef();
  var canvas = useRef({});

  useEffect(function () {
    ctx.current = canvasRef.current.getContext("2d");
  }, []);

  useEffect(function () {
    canvas.current = document.getElementById(id) || {};
    ctx.current.clearRect(0, 0, canvas.current.width, canvas.current.height);
    ctx.current.globalAlpha = opacity;
    ctx.current.fillStyle = color;
    ctx.current.fillRect(x, y, width, height);
    ctx.current.lineWidth = .2;
    ctx.current.strokeStyle = "#FF0000";
    ctx.current.strokeRect(x, y, width, height);
  }, [x, y, height, width, id, color, opacity]);

  return React.createElement(
    "section",
    { style: { width: "100%", height: "100%" } },
    React.createElement("canvas", { style: { width: "100%", height: "100%" }, ref: canvasRef, id: id })
  );
};

ReactBlockHighlighter.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Unique id for the canvas element */
  id: PropTypes.string,
  /** x-coordinate of origin */
  x: PropTypes.number,
  /** y-coordinate of origin */
  y: PropTypes.number,
  /** Height of the rectangle to be highlighted */
  height: PropTypes.number,
  /** Width of the rectangle to be highlighted */
  width: PropTypes.number,
  /** Opacity of the rectangle to be highlighted */
  opacity: PropTypes.number,
  /** Color of the rectangle to be highlighted */
  color: PropTypes.string
} : {};

ReactBlockHighlighter.defaultProps = {
  id: "block-highlight-canvas",
  opacity: .5,
  color: "#ffff00",
  x: 0,
  y: 0
};

export default ReactBlockHighlighter;

==> react-block-highlight-1.0.4.tgz: package/es/index.js <==
import React, { useEffect, useRef } from "react";
import PropTypes from 'prop-types';
/**
 * React Component to highlight any part of the containing block in reactangle size.
 */

var ReactBlockHighlighter = function ReactBlockHighlighter(_ref) {
  var id = _ref.id,
      x = _ref.x,
      y = _ref.y,
      height = _ref.height,
      width = _ref.width,
      opacity = _ref.opacity,
      color = _ref.color;

  var canvasRef = useRef(null);
  var ctx = useRef();
  var canvas = useRef({});

  useEffect(function () {
    ctx.current = canvasRef.current.getContext("2d");
  }, []);

  useEffect(function () {
    canvas.current = document.getElementById(id) || {};
    ctx.current.clearRect(0, 0, canvas.current.width, canvas.current.height);
    ctx.current.globalAlpha = opacity;
    ctx.current.fillStyle = color;
    ctx.current.fillRect(x, y, width, height);
    ctx.current.lineWidth = .2;
    ctx.current.strokeStyle = "#FF0000";
    ctx.current.strokeRect(x, y, width, height);
  }, [x, y, height, width, id, color, opacity]);

  return React.createElement("canvas", { style: { width: "100%", height: "100%" }, ref: canvasRef, id: id });
};

ReactBlockHighlighter.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Unique id for the canvas element */
  id: PropTypes.string,
  /** x-coordinate of starting point */
  x: PropTypes.number,
  /** y-coordinate of starting point */
  y: PropTypes.number,
  /** Height of the area to be highlighted */
  height: PropTypes.number,
  /** Width of the area to be highlighted */
  width: PropTypes.number,
  /** Opacity of the area to be highlighted */
  opacity: PropTypes.number,
  /** Color of the area to be highlighted */
  color: PropTypes.string
} : {};

ReactBlockHighlighter.defaultProps = {
  id: "block-highlight-canvas",
  opacity: .5,
  color: "#ffff00",
  x: 0,
  y: 0,
  width: 250,
  height: 20
};

export default ReactBlockHighlighter;
